@@ -1,4 +1,4 @@
 from .classifier import Classifier
 from .discriminator import Discriminator
 from .mnist import MNISTFeatures
-from .pretrained import mnistC, mnistG
+from .pretrained import mnistC, mnistG, office31C, office31G
